from setuptools import setup

setup(
    name='ani-m-package',
    version='0.1.0',
    description='Python package to print donut.',
    url='',
    author='Ani Marutyan',
    author_email='ani_marutyan@edu.aua.am',
    license='BSD 2-clause',
    packages=['ani-m-package'],
    install_requires=['pandas',
                      'scipy',
                      'matplotlib'
                      ],
)
